==> egov-common-1.0.8-sources.jar: com/gtis/plat/service/SysAuthorService.java <==
package com.gtis.plat.service;

import com.gtis.plat.vo.PfPartitionInfoVo;
import org.dom4j.Document;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

public interface SysAuthorService {

    /**
     * 任务列表 功能分区的可用列表
     *
     * @param taskId
     * @param rId
     */
    public abstract List<PfPartitionInfoVo> getTaskFormFunAuthorList(
            String taskId, String roles, String rId);

    public abstract List<PfPartitionInfoVo> getTaskFormAuthorList(String taskId, String roles, String rId);


    public abstract List<PfPartitionInfoVo> getProjectResrouceFunAuthorList(
            String proid, String roles, String rId);

    public abstract List<PfPartitionInfoVo> getSystemResrouceFunAuthorList(String roles, String rId);

    /**
     * 任务列表
     *
     * @param doc
     * @param taskId
     * @param resourceId
     */
    public abstract void processXmlDocument(Document doc, String taskId,
                                            String resourceId);

    /**
     * 项目列表
     *
     * @param doc
     * @param taskId
     * @param resourceId
     */
    public abstract void processProjectXmlDocument(Document doc,
                                                   HttpServletRequest request, String resourceId);

    /**
     * 系统主界面
     *
     * @param doc
     * @param lstElement
     */
    public abstract void processSystemXmlDocument(Document doc,
                                                  HttpServletRequest request, String resourceId);

    public abstract void processXmlReadOnly(Document doc);

    public abstract String getAuthorJsHtml(List<PfPartitionInfoVo> lstElement);

    public boolean queryTaskElement(String wiid, String taskid, String rId, String eleName);

}

==> egov-common-1.1.12.4-sources.jar: com/gtis/plat/service/SysAuthorService.java <==
package com.gtis.plat.service;

import com.gtis.plat.vo.PfPartitionInfoVo;
import org.dom4j.Document;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

public interface SysAuthorService {

    /**
     * 任务列表 功能分区的可用列表
     *
     * @param taskId
     * @param rId
     */
    public abstract List<PfPartitionInfoVo> getTaskFormFunAuthorList(
            String taskId, String roles, String rId);

    public abstract List<PfPartitionInfoVo> getTaskFormAuthorList(String taskId, String roles, String rId);


    public abstract List<PfPartitionInfoVo> getProjectResrouceFunAuthorList(
            String proid, String roles, String rId);

    public abstract List<PfPartitionInfoVo> getSystemResrouceFunAuthorList(String roles, String rId);

    /**
     * 任务列表
     *
     * @param doc
     * @param taskId
     * @param resourceId
     */
    public abstract void processXmlDocument(Document doc, String taskId,
                                            String resourceId);

    /**
     * 项目列表
     *
     * @param doc
     * @param taskId
     * @param resourceId
     */
    public abstract void processProjectXmlDocument(Document doc,
                                                   HttpServletRequest request, String resourceId);

    /**
     * 系统主界面
     *
     * @param doc
     * @param lstElement
     */
    public abstract void processSystemXmlDocument(Document doc,
                                                  HttpServletRequest request, String resourceId);

    public abstract void processXmlReadOnly(Document doc);

    public abstract String getAuthorJsHtml(List<PfPartitionInfoVo> lstElement);

    public boolean queryTaskElement(String wiid, String taskid, String rId, String eleName);

    /**
     * 帆软项目列表获取实例权限
     * @param proid
     * @param roles
     * @param rId
     * @return
     */
    public List<PfPartitionInfoVo> getProjectAllResrouceAuthorList(String proid,String roles, String rId);

    /**
     * 从系统主界面进入的资源权限,只读列表
     *
     * @param rId
     * @param rolesId
     * @return
     */
    public List<PfPartitionInfoVo> getSystemResrouceAuthorList(String rId, String rolesId);

}
